This is an automated email from Gerrit.

Spencer Oliver ([email protected]) just uploaded a new patch set to Gerrit, 
which you can find at http://openocd.zylin.com/473

-- gerrit

commit daad941787aed882b539d5aa7c89a308f770788e
Author: Spencer Oliver <[email protected]>
Date:   Tue Feb 21 10:13:21 2012 +0000

    jtag: use correct tap -ignore-version mask
    
    when -ignore-version is used we should mask of the upper 4bits not 8bits.
    
    Change-Id: I9ffe24c2aeeb414677357a647609fdf018890194
    Signed-off-by: Spencer Oliver <[email protected]>

diff --git a/doc/openocd.texi b/doc/openocd.texi
index 4bff740..2d4e83f 100644
--- a/doc/openocd.texi
+++ b/doc/openocd.texi
@@ -3369,7 +3369,7 @@ hardware to find these values.
 option.  When vendors put out multiple versions of a chip, or use the same
 JTAG-level ID for several largely-compatible chips, it may be more practical
 to ignore the version field than to update config files to handle all of
-the various chip IDs.
+the various chip IDs. The version field is defined as bit 28-31 of the IDCODE.
 @item @code{-ircapture} @var{NUMBER}
 @*The bit pattern loaded by the TAP into the JTAG shift register
 on entry to the @sc{ircapture} state, such as 0x01.
diff --git a/src/jtag/core.c b/src/jtag/core.c
index 6de168e..a36345b 100644
--- a/src/jtag/core.c
+++ b/src/jtag/core.c
@@ -958,8 +958,8 @@ static bool jtag_examine_chain_match_tap(const struct 
jtag_tap *tap)
        if (0 == tap->expected_ids_cnt && !idcode)
                return true;
 
-       /* optionally ignore the JTAG version field */
-       uint32_t mask = tap->ignore_version ? ~(0xff << 24) : ~0;
+       /* optionally ignore the JTAG version field - bits 28-31 of IDCODE */
+       uint32_t mask = tap->ignore_version ? ~(0xf << 28) : ~0;
 
        idcode &= mask;
 

-- 

------------------------------------------------------------------------------
Keep Your Developer Skills Current with LearnDevNow!
The most comprehensive online learning library for Microsoft developers
is just $99.99! Visual Studio, SharePoint, SQL - plus HTML5, CSS3, MVC3,
Metro Style Apps, more. Free future releases when you subscribe now!
http://p.sf.net/sfu/learndevnow-d2d
_______________________________________________
OpenOCD-devel mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/openocd-devel

Reply via email to